/*******************************************************************************
* File Name: Timer_AETR_PM.c
* Version 2.70
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "Timer_AETR.h"

static Timer_AETR_backupStruct Timer_AETR_backup;


/*******************************************************************************
* Function Name: Timer_AETR_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Timer_AETR_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void Timer_AETR_SaveConfig(void) 
{
    #if (!Timer_AETR_UsingFixedFunction)
        Timer_AETR_backup.TimerUdb = Timer_AETR_ReadCounter();
        Timer_AETR_backup.InterruptMaskValue = Timer_AETR_STATUS_MASK;
        #if (Timer_AETR_UsingHWCaptureCounter)
            Timer_AETR_backup.TimerCaptureCounter = Timer_AETR_ReadCaptureCount();
        #endif /* Back Up capture counter register  */

        #if(!Timer_AETR_UDB_CONTROL_REG_REMOVED)
            Timer_AETR_backup.TimerControlRegister = Timer_AETR_ReadControlRegister();
        #endif /* Backup the enable state of the Timer component */
    #endif /* Backup non retention registers in UDB implementation. All fixed function registers are retention */
}


/*******************************************************************************
* Function Name: Timer_AETR_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Timer_AETR_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void Timer_AETR_RestoreConfig(void) 
{   
    #if (!Timer_AETR_UsingFixedFunction)

        Timer_AETR_WriteCounter(Timer_AETR_backup.TimerUdb);
        Timer_AETR_STATUS_MASK =Timer_AETR_backup.InterruptMaskValue;
        #if (Timer_AETR_UsingHWCaptureCounter)
            Timer_AETR_SetCaptureCount(Timer_AETR_backup.TimerCaptureCounter);
        #endif /* Restore Capture counter register*/

        #if(!Timer_AETR_UDB_CONTROL_REG_REMOVED)
            Timer_AETR_WriteControlRegister(Timer_AETR_backup.TimerControlRegister);
        #endif /* Restore the enable state of the Timer component */
    #endif /* Restore non retention registers in the UDB implementation only */
}


/*******************************************************************************
* Function Name: Timer_AETR_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Timer_AETR_backup.TimerEnableState:  Is modified depending on the
*  enable state of the block before entering sleep mode.
*
*******************************************************************************/
void Timer_AETR_Sleep(void) 
{
    #if(!Timer_AETR_UDB_CONTROL_REG_REMOVED)
        /* Save Counter's enable state */
        if(Timer_AETR_CTRL_ENABLE == (Timer_AETR_CONTROL & Timer_AETR_CTRL_ENABLE))
        {
            /* Timer is enabled */
            Timer_AETR_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            Timer_AETR_backup.TimerEnableState = 0u;
        }
    #endif /* Back up enable state from the Timer control register */
    Timer_AETR_Stop();
    Timer_AETR_SaveConfig();
}


/*******************************************************************************
* Function Name: Timer_AETR_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Timer_AETR_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Timer_AETR_Wakeup(void) 
{
    Timer_AETR_RestoreConfig();
    #if(!Timer_AETR_UDB_CONTROL_REG_REMOVED)
        if(Timer_AETR_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                Timer_AETR_Enable();
        } /* Do nothing if Timer was disabled before */
    #endif /* Remove this code section if Control register is removed */
}


/* [] END OF FILE */
